@@ -5,15 +5,18 @@ import os
 import base64
 
 def encrypt(key: str, content: str):
+    key = RSA.import_key(key)
     return base64.b64encode(PKCS1_OAEP.new(key).encrypt(content.encode('utf-8'))).decode('utf-8')
 
 
-def decrypt(key: str, content: str):
-    return PKCS1_OAEP.new(key).decrypt(base64.b64decode(content.encode('utf-8'))).decode('utf-8')
+def decrypt(pkey: str, content: str):
+    pkey = RSA.import_key(key)
+    return PKCS1_OAEP.new(pkey).decrypt(base64.b64decode(content.encode('utf-8'))).decode('utf-8')
 
 
 def big_encrypt(key: str, content: str) -> (str, str):
     aes_key = get_random_bytes(16)
+    rsa_key = RSA.import_key(key)
 
     # Encrypt the data
     cipher = AES.new(aes_key, AES.MODE_EAX)
@@ -28,6 +31,7 @@ def big_encrypt(key: str, content: str) -> (str, str):
 
 
 def big_decrypt(key: str, aes_string: str, content: str):
+    rsa_key = RSA.import_key(key)
     enc_key, nonce = aes_string.split(',')
 
     # Decrypt the aes key
